@@ -8,13 +8,18 @@ package Object::Pad;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
 require XSLoader;
 XSLoader::load( __PACKAGE__, $VERSION );
 
+# So that feature->import will work in `class`
+require feature;
+require experimental;
+require indirect;
+
 =head1 NAME
 
 C<Object::Pad> - a simple syntax for lexical slot-based objects
@@ -80,6 +85,10 @@ to store references to anonymous arrays or hashes.
       ...
    }
 
+   method NAME (SIGNATURE) {
+      ...
+   }
+
    method NAME :attrs... {
       ...
    }
@@ -90,6 +99,8 @@ except that within the body of the method all of the member attributes
 lexical called C<$self> which contains the invocant object directly; it will
 already have been shifted from the C<@_> array.
 
+The C<signatures> feature is automatically enabled for method declarations.
+
 A list of attributes may be supplied as for C<sub>. The most useful of these
 is C<:lvalue>, allowing easy creation of read-write accessors for slots.
 
@@ -102,6 +113,16 @@ is C<:lvalue>, allowing easy creation of read-write accessors for slots.
    my $c = Counter->new;
    $c->count++;
 
+=head1 IMPLIED PRAGMATA
+
+In order to encourage users to write clean, modern code, the body of the
+C<class> block acts as if the following pragmata are in effect:
+
+   use strict;
+   use warnings;
+   no indirect ':fatal';
+   use feature 'signatures';
+
 =cut
 
 sub import
@@ -139,10 +160,6 @@ Subclassing. Single-inheritence is easier than multi so maybe that first.
 
 =item *
 
-Sub signatures
-
-=item *
-
 Detect and croak on attempts to invoke C<method> subs on non-instances.
 
 =item *
